qtmobility/src/contacts/requests/qcontactlocalidfetchrequest.cpp
changeset 5 453da2cfceef
parent 4 90517678cc4f
child 11 06b8e2af4411
--- a/qtmobility/src/contacts/requests/qcontactlocalidfetchrequest.cpp	Mon May 03 13:18:40 2010 +0300
+++ b/qtmobility/src/contacts/requests/qcontactlocalidfetchrequest.cpp	Fri May 14 16:41:33 2010 +0300
@@ -57,9 +57,9 @@
   \ingroup contacts-requests
  */
 
-/*! Constructs a new contact id fetch request */
-QContactLocalIdFetchRequest::QContactLocalIdFetchRequest()
-    : QContactAbstractRequest(new QContactLocalIdFetchRequestPrivate)
+/*! Constructs a new contact id fetch request whose parent is the specified \a parent */
+QContactLocalIdFetchRequest::QContactLocalIdFetchRequest(QObject* parent)
+    : QContactAbstractRequest(new QContactLocalIdFetchRequestPrivate, parent)
 {
 }